"""Patch photologue. There are migrations for this but the patch ensures the
tests pass, because tests skip South migrations."""

from photologue.models import ImageModel, PhotoSize


ImageModel._meta.get_field("image").blank = True
ImageModel._meta.get_field("image").null = True
PhotoSize._meta.get_field("name").max_length = 64


# More patches to handle null image
def ImageModel_decorator(func):
    def new(self, *args, **kwargs):
        if not self.image:
            return
        return func(self, *args, **kwargs)
    return new

ImageModel.create_size = ImageModel_decorator(ImageModel.create_size)
ImageModel.remove_size = ImageModel_decorator(ImageModel.remove_size)


def ImageModel_delete(self):
    assert self._get_pk_val() is not None, "%s object can't be deleted because its %s attribute is set to None." % \
        (self._meta.object_name, self._meta.pk.attname)
    self.clear_cache()
    super(ImageModel, self).delete()
    if self.image:
        self.image.storage.delete(self.image.name)

ImageModel.delete = ImageModel_delete



import warnings

from django import template
from django.template import TemplateDoesNotExist
from django.contrib.contenttypes.models import ContentType
from django.template.loader import render_to_string
from django.conf import settings


register = template.Library()


@register.tag
def render_object(parser, token):
    try:
        tag_name, obj, type = token.split_contents()
    except ValueError:
        raise template.TemplateSyntaxError(
            'render_object tag requires 2 arguments (obj, type), %s given' % \
                    (len(token.split_contents()) - 1)
            )
    return RenderObjectNode(obj, type)


class RenderObjectNode(template.Node):
    def __init__(self, obj, type):
        self.obj = template.Variable(obj)
        self.type = template.Variable(type)

    def render(self, context):
        obj = self.obj.resolve(context)
        # Fallback handling because object_* tags now defer to render_object
        try:
            type = self.type.resolve(context)
        except template.VariableDoesNotExist:
            type = self.type

        # Update context
        context.push()
        context['object'] = obj

        # Template names follow typical Django naming convention but also
        # provides legacy handling.
        ctype = ContentType.objects.get_for_model(obj)
        template_names = (
            "%s/inclusion_tags/%s_%s.html" % (ctype.app_label, ctype.model, type),
            "%s/%s/inclusion_tags/object_%s.html" % (ctype.app_label, ctype.model, type),
            "%s/inclusion_tags/object_%s.html" % (ctype.app_label, type),
            "jmbo/inclusion_tags/object_%s.html" % type,
            "jmbo/inclusion_tags/modelbase_%s.html" % type
        )
        rendered = False
        for template_name in template_names:
            try:
                response = render_to_string(template_name, context)
                rendered = True
                break
            except TemplateDoesNotExist:
                pass

        context.pop()

        if not rendered:
            if settings.TEMPLATE_DEBUG:
                raise TemplateDoesNotExist({
                    'content_type': ctype.app_label,
                    'model': ctype.model,
                    'type': type
                })
            else:
                response = ''

        return response


@register.tag
def object_header(parser, token):
    try:
        tag_name, obj = token.split_contents()
    except ValueError:
        raise template.TemplateSyntaxError(
            'object_header tag requires 1 argument obj, %s given' % \
                    (len(token.split_contents()) - 1)
            )
    return RenderObjectNode(obj, 'header')


@register.tag
def object_footer(parser, token):
    try:
        tag_name, obj = token.split_contents()
    except ValueError:
        raise template.TemplateSyntaxError(
            'object_footer tag requires 1 argument obj, %s given' % \
                    (len(token.split_contents()) - 1)
            )
    return RenderObjectNode(obj, 'footer')


@register.tag
def object_comments(parser, token):
    try:
        tag_name, obj = token.split_contents()
    except ValueError:
        raise template.TemplateSyntaxError(
            'object_comments tag requires 1 argument obj, %s given' % \
                    (len(token.split_contents()) - 1)
            )
    return RenderObjectCommentsNode(obj, 'comments')


class RenderObjectCommentsNode(RenderObjectNode):

    def render(self, context):
        obj = self.obj.resolve(context)
        can_comment, code = obj.can_comment(context['request'])
        context.update({
            'object': obj,
            'can_render_comment_form': can_comment,
            'can_comment_code': code
        })
        return super(RenderObjectCommentsNode, self).render(context)


@register.tag
def view_modifier(parser, token):
    """
    Output view modifier.
    """
    try:
        tag_name, view_modifier = token.split_contents()
    except ValueError:
        raise template.TemplateSyntaxError(
            'view_modifier tag requires 1 argument (view_modifier), %s given' \
                    % (len(token.split_contents()) - 1)
            )
    return ViewModifierNode(view_modifier)


class ViewModifierNode(template.Node):
    def __init__(self, view_modifier):
        self.view_modifier = template.Variable(view_modifier)

    def render(self, context):
        view_modifier = self.view_modifier.resolve(context)
        context = {
            'request': context['request'],
            'view_modifier': view_modifier,
        }
        return render_to_string(
            'jmbo/inclusion_tags/view_modifier.html',
            context
        )



from django.contrib.admin.views.decorators import staff_member_required
from django.http import HttpResponse
from django.views.decorators.http import require_POST
from django.http import HttpResponseForbidden

from jmbo.models import ModelBase


@staff_member_required
def publish_ajax(request):
    obj = ModelBase.objects.get(id=request.REQUEST['id'])
    obj.publish()
    return HttpResponse('published')


@staff_member_required
def unpublish_ajax(request):
    obj = ModelBase.objects.get(id=request.REQUEST['id'])
    obj.unpublish()
    return HttpResponse('unpublished')


@require_POST
@staff_member_required
def edit_autosave_ajax(request):
    obj = ModelBase.objects.get(id=request.POST['id']).as_leaf_class()

    # Check permission
    model = type(obj)
    permission = model._meta.app_label + '.' + model._meta.get_change_permission()
    if not request.user.has_perm(permission):
        return HttpResponseForbidden('You are not allowed to change this object')

    changes = False
    for field in getattr(obj, 'autosave_fields', []):
        new_value = request.POST.get(field)
        old_value = getattr(obj, field)
        if new_value != old_value:
            setattr(obj, field, new_value)
            changes = True
    if changes:
        obj.save()

    return HttpResponse('1')



from django.conf.urls import url
from django.core.urlresolvers import NoReverseMatch

from tastypie.resources import ModelResource

from jmbo.models import ModelBase


class ModelBaseResource(ModelResource):

    class Meta:
        queryset = ModelBase.permitted.all()
        resource_name = 'modelbase'

    def get_resource_uri(self, bundle_or_obj=None, url_name='api_dispatch_list'):
        """The resource_uri must point to the leaf class if possible"""
        if bundle_or_obj is not None:
            try:
                leaf = bundle_or_obj.obj.as_leaf_class()
            except AttributeError:
                pass
            else:
                # Prevent circular import
                from jmbo.urls import v1_api
                # Registry convention
                resource = v1_api._registry.get(leaf.__class__.__name__.lower())
                if resource:
                   return resource.get_resource_uri(leaf, url_name)

        return super(ModelBaseResource, self).get_resource_uri(bundle_or_obj, url_name)

    def dehydrate(self, bundle):
        bundle.data['permalink'] = bundle.obj.get_absolute_url()
        bundle.data['image_detail_url'] = ''
        if bundle.obj.image:
            try:
                bundle.data['image_detail_url'] = bundle.obj.image_detail_url
            except AttributeError:
                pass
        return bundle



from django import template

register = template.Library()


@register.inclusion_tag('admin/jmbo/submit_line.html', takes_context=True)
def submit_row(context):
    """
    Based on django/contrib/admin/templatetags/admin_modify.py version 1.6.
    Some rules have been changed.
    """
    opts = context['opts']
    change = context['change']
    is_popup = context['is_popup']
    save_as = context['save_as']
    ctx = {
        'opts': opts,
        'show_delete_link': (not is_popup and context['has_delete_permission']
                              and change and context.get('show_delete', True)),
        'show_save_as_new': not is_popup and change and save_as,
        'show_save_and_add_another': context['has_add_permission'] and
                            not is_popup,
        'show_save_and_continue': not is_popup and context['has_change_permission'],
        'is_popup': is_popup,
        'show_save': True,
        'preserved_filters': context.get('preserved_filters'),
    }
    if context.get('original') is not None:
        ctx['original'] = context['original']

    if 'original' in context:
        ctx['show_save_and_publish'] = context['original'].state == 'unpublished'
        ctx['show_save_and_unpublish'] = context['original'].state == 'published'
    else:
        ctx['show_save_and_publish'] = True
        ctx['show_save_and_unpublish'] = False

    return ctx



# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    depends_on = (
        ("category", "0001_initial"),
        ("photologue", "0009_auto__del_galleryupload"),
    )

    def forwards(self, orm):

        # Adding model 'ModelBase'
        db.create_table('jmbo_modelbase', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('image', self.gf('django.db.models.fields.files.ImageField')(max_length=100, blank=True)),
            ('date_taken', self.gf('django.db.models.fields.DateTimeField')(null=True, blank=True)),
            ('view_count', self.gf('django.db.models.fields.PositiveIntegerField')(default=0)),
            ('crop_from', self.gf('django.db.models.fields.CharField')(default='center', max_length=10, blank=True)),
            ('effect', self.gf('django.db.models.fields.related.ForeignKey')(blank=True, related_name='modelbase_related', null=True, to=orm['photologue.PhotoEffect'])),
            ('state', self.gf('django.db.models.fields.CharField')(default='unpublished', max_length=32, null=True, blank=True)),
            ('publish_on', self.gf('django.db.models.fields.DateTimeField')(null=True, blank=True)),
            ('retract_on', self.gf('django.db.models.fields.DateTimeField')(null=True, blank=True)),
            ('slug', self.gf('django.db.models.fields.SlugField')(unique=True, max_length=255, db_index=True)),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=200)),
            ('description', self.gf('django.db.models.fields.TextField')(null=True, blank=True)),
            ('created', self.gf('django.db.models.fields.DateTimeField')(blank=True)),
            ('modified', self.gf('django.db.models.fields.DateTimeField')()),
            ('owner', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['auth.User'], null=True, blank=True)),
            ('content_type', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['contenttypes.ContentType'], null=True)),
            ('class_name', self.gf('django.db.models.fields.CharField')(max_length=32, null=True)),
            ('primary_category', self.gf('django.db.models.fields.related.ForeignKey')(blank=True, related_name='primary_modelbase_set', null=True, to=orm['category.Category'])),
            ('comments_enabled', self.gf('django.db.models.fields.BooleanField')(default=True)),
            ('anonymous_comments', self.gf('django.db.models.fields.BooleanField')(default=True)),
            ('comments_closed', self.gf('django.db.models.fields.BooleanField')(default=False)),
            ('likes_enabled', self.gf('django.db.models.fields.BooleanField')(default=True)),
            ('anonymous_likes', self.gf('django.db.models.fields.BooleanField')(default=True)),
            ('likes_closed', self.gf('django.db.models.fields.BooleanField')(default=False)),
        ))
        db.send_create_signal('jmbo', ['ModelBase'])

        # Adding M2M table for field categories on 'ModelBase'
        db.create_table('jmbo_modelbase_categories', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('modelbase', models.ForeignKey(orm['jmbo.modelbase'], null=False)),
            ('category', models.ForeignKey(orm['category.category'], null=False))
        ))
        db.create_unique('jmbo_modelbase_categories', ['modelbase_id', 'category_id'])

        # Adding M2M table for field tags on 'ModelBase'
        db.create_table('jmbo_modelbase_tags', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('modelbase', models.ForeignKey(orm['jmbo.modelbase'], null=False)),
            ('tag', models.ForeignKey(orm['category.tag'], null=False))
        ))
        db.create_unique('jmbo_modelbase_tags', ['modelbase_id', 'tag_id'])

        # Adding M2M table for field sites on 'ModelBase'
        db.create_table('jmbo_modelbase_sites', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('modelbase', models.ForeignKey(orm['jmbo.modelbase'], null=False)),
            ('site', models.ForeignKey(orm['sites.site'], null=False))
        ))
        db.create_unique('jmbo_modelbase_sites', ['modelbase_id', 'site_id'])

        # Adding M2M table for field publishers on 'ModelBase'
        db.create_table('jmbo_modelbase_publishers', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('modelbase', models.ForeignKey(orm['jmbo.modelbase'], null=False)),
            ('publisher', models.ForeignKey(orm['publisher.publisher'], null=False))
        ))
        db.create_unique('jmbo_modelbase_publishers', ['modelbase_id', 'publisher_id'])

        # Adding model 'Pin'
        db.create_table('jmbo_pin', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('content', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['jmbo.ModelBase'])),
            ('category', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['category.Category'])),
        ))
        db.send_create_signal('jmbo', ['Pin'])

        # Adding model 'Relation'
        db.create_table('jmbo_relation', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('source_content_type', self.gf('django.db.models.fields.related.ForeignKey')(related_name='relation_source_content_type', to=orm['contenttypes.ContentType'])),
            ('source_object_id', self.gf('django.db.models.fields.PositiveIntegerField')()),
            ('target_content_type', self.gf('django.db.models.fields.related.ForeignKey')(related_name='relation_target_content_type', to=orm['contenttypes.ContentType'])),
            ('target_object_id', self.gf('django.db.models.fields.PositiveIntegerField')()),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=32, db_index=True)),
        ))
        db.send_create_signal('jmbo', ['Relation'])

        # Adding unique constraint on 'Relation', fields ['source_content_type', 'source_object_id', 'target_content_type', 'target_object_id', 'name']
        db.create_unique('jmbo_relation', ['source_content_type_id', 'source_object_id', 'target_content_type_id', 'target_object_id', 'name'])


    def backwards(self, orm):
        
        # Removing unique constraint on 'Relation', fields ['source_content_type', 'source_object_id', 'target_content_type', 'target_object_id', 'name']
        db.delete_unique('jmbo_relation', ['source_content_type_id', 'source_object_id', 'target_content_type_id', 'target_object_id', 'name'])

        # Deleting model 'ModelBase'
        db.delete_table('jmbo_modelbase')

        # Removing M2M table for field categories on 'ModelBase'
        db.delete_table('jmbo_modelbase_categories')

        # Removing M2M table for field tags on 'ModelBase'
        db.delete_table('jmbo_modelbase_tags')

        # Removing M2M table for field sites on 'ModelBase'
        db.delete_table('jmbo_modelbase_sites')

        # Removing M2M table for field publishers on 'ModelBase'
        db.delete_table('jmbo_modelbase_publishers')

        # Deleting model 'Pin'
        db.delete_table('jmbo_pin')

        # Deleting model 'Relation'
        db.delete_table('jmbo_relation')


    models = {
        'auth.group': {
            'Meta': {'object_name': 'Group'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '80'}),
            'permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'})
        },
        'auth.permission': {
            'Meta': {'ordering': "('content_type__app_label', 'content_type__model', 'codename')", 'unique_together': "(('content_type', 'codename'),)", 'object_name': 'Permission'},
            'codename': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        },
        'auth.user': {
            'Meta': {'object_name': 'User'},
            'date_joined': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}),
            'first_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'groups': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Group']", 'symmetrical': 'False', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'is_staff': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'is_superuser': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'last_login': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'last_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'password': ('django.db.models.fields.CharField', [], {'max_length': '128'}),
            'user_permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'}),
            'username': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '30'})
        },
        'category.category': {
            'Meta': {'ordering': "('title',)", 'object_name': 'Category'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'parent': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['category.Category']", 'null': 'True', 'blank': 'True'}),
            'slug': ('django.db.models.fields.SlugField', [], {'unique': 'True', 'max_length': '255', 'db_index': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '200'})
        },
        'category.tag': {
            'Meta': {'ordering': "('title',)", 'object_name': 'Tag'},
            'categories': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'to': "orm['category.Category']", 'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'slug': ('django.db.models.fields.SlugField', [], {'unique': 'True', 'max_length': '255', 'db_index': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '200'})
        },
        'contenttypes.contenttype': {
            'Meta': {'ordering': "('name',)", 'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'jmbo.modelbase': {
            'Meta': {'ordering': "('-created',)", 'object_name': 'ModelBase'},
            'anonymous_comments': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'anonymous_likes': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'categories': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'to': "orm['category.Category']", 'null': 'True', 'blank': 'True'}),
            'class_name': ('django.db.models.fields.CharField', [], {'max_length': '32', 'null': 'True'}),
            'comments_closed': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'comments_enabled': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']", 'null': 'True'}),
            'created': ('django.db.models.fields.DateTimeField', [], {'blank': 'True'}),
            'crop_from': ('django.db.models.fields.CharField', [], {'default': "'center'", 'max_length': '10', 'blank': 'True'}),
            'date_taken': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            'description': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'effect': ('django.db.models.fields.related.ForeignKey', [], {'blank': 'True', 'related_name': "'modelbase_related'", 'null': 'True', 'to': "orm['photologue.PhotoEffect']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('django.db.models.fields.files.ImageField', [], {'max_length': '100', 'blank': 'True'}),
            'likes_closed': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'likes_enabled': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'modified': ('django.db.models.fields.DateTimeField', [], {}),
            'owner': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['auth.User']", 'null': 'True', 'blank': 'True'}),
            'primary_category': ('django.db.models.fields.related.ForeignKey', [], {'blank': 'True', 'related_name': "'primary_modelbase_set'", 'null': 'True', 'to': "orm['category.Category']"}),
            'publish_on': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            'publishers': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'to': "orm['publisher.Publisher']", 'null': 'True', 'blank': 'True'}),
            'retract_on': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            'sites': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'to': "orm['sites.Site']", 'null': 'True', 'blank': 'True'}),
            'slug': ('django.db.models.fields.SlugField', [], {'unique': 'True', 'max_length': '255', 'db_index': 'True'}),
            'state': ('django.db.models.fields.CharField', [], {'default': "'unpublished'", 'max_length': '32', 'null': 'True', 'blank': 'True'}),
            'tags': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'to': "orm['category.Tag']", 'null': 'True', 'blank': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '200'}),
            'view_count': ('django.db.models.fields.PositiveIntegerField', [], {'default': '0'})
        },
        'jmbo.pin': {
            'Meta': {'object_name': 'Pin'},
            'category': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['category.Category']"}),
            'content': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['jmbo.ModelBase']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'})
        },
        'jmbo.relation': {
            'Meta': {'unique_together': "(('source_content_type', 'source_object_id', 'target_content_type', 'target_object_id', 'name'),)", 'object_name': 'Relation'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '32', 'db_index': 'True'}),
            'source_content_type': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'relation_source_content_type'", 'to': "orm['contenttypes.ContentType']"}),
            'source_object_id': ('django.db.models.fields.PositiveIntegerField', [], {}),
            'target_content_type': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'relation_target_content_type'", 'to': "orm['contenttypes.ContentType']"}),
            'target_object_id': ('django.db.models.fields.PositiveIntegerField', [], {})
        },
        'photologue.photoeffect': {
            'Meta': {'object_name': 'PhotoEffect'},
            'background_color': ('django.db.models.fields.CharField', [], {'default': "'#FFFFFF'", 'max_length': '7'}),
            'brightness': ('django.db.models.fields.FloatField', [], {'default': '1.0'}),
            'color': ('django.db.models.fields.FloatField', [], {'default': '1.0'}),
            'contrast': ('django.db.models.fields.FloatField', [], {'default': '1.0'}),
            'description': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'filters': ('django.db.models.fields.CharField', [], {'max_length': '200', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '30'}),
            'reflection_size': ('django.db.models.fields.FloatField', [], {'default': '0'}),
            'reflection_strength': ('django.db.models.fields.FloatField', [], {'default': '0.59999999999999998'}),
            'sharpness': ('django.db.models.fields.FloatField', [], {'default': '1.0'}),
            'transpose_method': ('django.db.models.fields.CharField', [], {'max_length': '15', 'blank': 'True'})
        },
        'publisher.publisher': {
            'Meta': {'object_name': 'Publisher'},
            'class_name': ('django.db.models.fields.CharField', [], {'max_length': '32', 'null': 'True'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']", 'null': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '64'})
        },
        'secretballot.vote': {
            'Meta': {'unique_together': "(('token', 'content_type', 'object_id'),)", 'object_name': 'Vote'},
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'object_id': ('django.db.models.fields.PositiveIntegerField', [], {}),
            'token': ('django.db.models.fields.CharField', [], {'max_length': '50'}),
            'vote': ('django.db.models.fields.SmallIntegerField', [], {})
        },
        'sites.site': {
            'Meta': {'ordering': "('domain',)", 'object_name': 'Site', 'db_table': "'django_site'"},
            'domain': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        }
    }

    complete_apps = ['jmbo']



from django.test import Client
from django.core.handlers.base import BaseHandler
from django.core.handlers.wsgi import WSGIRequest


class RequestFactory(Client):
    """
    Taken from DjangoSnippet 963, http://www.djangosnippets.org/snippets/963/

    Class that lets you create mock Request objects for use in testing.

    Usage:

    rf = RequestFactory()
    get_request = rf.get('/hello/')
    post_request = rf.post('/submit/', {'foo': 'bar'})

    This class re-uses the django.test.client.Client interface, docs here:
    http://www.djangoproject.com/documentation/testing/#the-test-client

    Once you have a request object you can pass it to any view function,
    just as if that view had been hooked up using a URLconf.

    """
    def request(self, **request):
        """
        Similar to parent class, but returns the request object as soon as it
        has created it.
        """
        environ = {
            'HTTP_COOKIE': self.cookies,
            'PATH_INFO': '/',
            'QUERY_STRING': '',
            'REQUEST_METHOD': 'GET',
            'SCRIPT_NAME': '',
            'SERVER_NAME': 'testserver',
            'SERVER_PORT': 80,
            'SERVER_PROTOCOL': 'HTTP/1.1',
        }
        environ.update(self.defaults)
        environ.update(request)
        request = WSGIRequest(environ)
        handler = BaseHandler()
        handler.load_middleware()
        for middleware_method in handler._request_middleware:
            middleware_method(request)

        return request



from setuptools import setup, find_packages

setup(
    name='jmbo',
    version='2.0.8',
    description='The Jmbo base product introduces a content type and various tools required to build Jmbo products.',
    long_description = open('README.rst', 'r').read() + open('AUTHORS.rst', 'r').read() + open('CHANGELOG.rst', 'r').read(),
    author='Praekelt Foundation',
    author_email='dev@praekelt.com',
    license='BSD',
    url='http://www.jmbo.org',
    packages = find_packages(),
    install_requires = [
        'Pillow',
        'pytz',
        'django>=1.4,<1.7',
        'django-category>=0.0.5',
        'django-likes>=0.0.8',
        'django-preferences',
        'django-publisher',             # legacy, required by migrations
        'django-sites-groups',
        'django-tastypie>=0.10,<0.12',  # 0.12 requires Django 1.7
        'django-celery',
        'django-generate',
        'django-pagination',
        'django-photologue>=3.1,<3.2',
        'django-ultracache',
        'south',
    ],
    include_package_data=True,
    tests_require=[
        'psycopg2',                     # we need a proper database
        #'django-atlas',                # todo - test suite to use geos
        'django-setuptest>=0.1.4',
    ],
    test_suite="setuptest.setuptest.SetupTestSuite",
    classifiers=[
        "Programming Language :: Python",
        "License :: OSI Approved :: BSD License",
        "Development Status :: 4 - Beta",
        "Operating System :: OS Independent",
        "Framework :: Django",
        "Intended Audience :: Developers",
        "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
    ],
    zip_safe=False,
)
